@@ -1,20 +1,14 @@
-//! The `cosmos-sdk-proto` crate provides access to the Cosmos SDK proto-defined structs.
-//! These are then re-exported in a module structure as close as possible to the proto files.
-//!
-//! The version strings are intentionally excluded, that way users may specify `cosmos-sdk` versions
-//! as a feature argument to this crate and not have to change their imports. For as much as that is
-//! worth considering that modules seem to show up and go away with every RC.
-//!
-//! TODO: actually implement features tag based compilation
-
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![doc = include_str!("../README.md")]
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/cosmos/cosmos-rust/main/.images/cosmos.png",
-    html_root_url = "https://docs.rs/cosmos-sdk-proto/0.6.3"
+    html_root_url = "https://docs.rs/cosmos-sdk-proto/0.8.0"
 )]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 #![forbid(unsafe_code)]
 #![warn(trivial_casts, trivial_numeric_casts, unused_import_braces)]
 
+pub use tendermint_proto as tendermint;
+
 /// The version (commit hash) of the Cosmos SDK used when generating this library.
 pub const COSMOS_SDK_VERSION: &str = include_str!("prost/COSMOS_SDK_COMMIT");
 
@@ -201,8 +195,9 @@ pub mod cosmos {
     }
 }
 
-#[cfg(feature = "cosmwasm")]
 /// CosmWasm protobuf definitions.
+#[cfg(feature = "cosmwasm")]
+#[cfg_attr(docsrs, doc(cfg(feature = "cosmwasm")))]
 pub mod cosmwasm {
     /// Messages and services handling CosmWasm.
     pub mod wasm {
